@@ -13,9 +13,9 @@
  * This hash routine is for case sensitive keys.  Specifically keys that
  * have been prefolded to an apppropriate case.
  */
-static __inline u_32int_t  cs_alist_hash (const char *s, u_32int_t *mask)
+static __inline uint32_t  cs_alist_hash (const char *s, uint32_t *mask)
 {
-	u_32int_t	x = 0;
+	uint32_t	x = 0;
 
 	if (s[0] != 0)
 	{
@@ -41,9 +41,9 @@ extern unsigned char *stricmp_tables[2];
  * This hash routine is for case insensitive keys.  Specifically keys that
  * cannot be prefolded to an appropriate case but are still insensitive
  */
-static __inline u_32int_t  ci_alist_hash (const char *s, u_32int_t *mask)
+static __inline uint32_t  ci_alist_hash (const char *s, uint32_t *mask)
 {
-	u_32int_t	x = 0;
+	uint32_t	x = 0;
 
 	if (s[0] != 0)
 	{
@@ -71,7 +71,7 @@ static __inline u_32int_t  ci_alist_hash (const char *s, u_32int_t *mask)
 typedef struct 
 {
 	char *		name;
-	u_32int_t	hash;
+	uint32_t	hash;
 	void *		data;
 } alist_item_;
 
@@ -93,7 +93,7 @@ typedef struct
 	int 		total_max;
 	alist_func 	func;
 	hash_type 	hash;
-} MAY_ALIAS alist;
+} alist;
 
 void *	add_to_alist 		(alist *, const char *, void *);
 void *	remove_from_alist 	(alist *, const char *);
