@@ -152,6 +152,7 @@
 #define DEFAULT_BANNER_EXPAND 0
 #define DEFAULT_BEEP 1
 #define DEFAULT_BEEP_MAX 3
+#define DEFAULT_BLANK_LINE_INDICATOR NULL
 #define DEFAULT_BLINK_VIDEO 1
 #define	DEFAULT_BOLD_VIDEO 1
 #define DEFAULT_BROKEN_AIXTERM 0
@@ -264,6 +265,7 @@
 #define DEFAULT_STATUS_PREFIX_WHEN_NOT_CURRENT ""
 #define DEFAULT_STATUS_QUERY " (Query: %Q)"
 #define DEFAULT_STATUS_SCROLLBACK " (Scroll)"
+#define DEFAULT_STATUS_SEQUENCE_POINT " {{{%P}}}"
 #define DEFAULT_STATUS_SERVER " (%S)"
 #define DEFAULT_STATUS_SSL_OFF "*RAW*"
 #define DEFAULT_STATUS_SSL_ON "*SSL*"
