@@ -238,7 +238,8 @@ sigfunc *init_signals (void);
 void	init_signal_names (void);
 const char *get_signal_name (int);
 int	get_signal_by_name (const char *);	/* Returns -1 on error */
-extern	volatile int    signals_caught[NSIG];
+
+extern	volatile sig_atomic_t	signals_caught[NSIG];
 
 #define BUILT_IN_COMMAND(x) \
 	void x (const char *command, char *args, const char *subargs)
