@@ -40,19 +40,19 @@
 /*
  * irc_version is what $J returns, its the common-name for the version.
  */
-const char irc_version[] = "EPIC5-2.1.12";
-const char useful_info[] = "epic5 2 1 12";
+const char irc_version[] = "EPIC5-2.1.13";
+const char useful_info[] = "epic5 2 1 13";
 
 /*
  * internal_version is what $V returns, its the integer-id for the
  * version, and corresponds to the date of release, YYYYMMDD.
  */ 
-const char internal_version[] = "20220615";
+const char internal_version[] = "20240614";
 
 /*
  * In theory, this number is incremented for every commit.
  */
-const unsigned long	commit_id = 2078;
+const unsigned long	commit_id = 2125;
 
 /*
  * As a way to poke fun at the current rage of naming releases after
@@ -60,7 +60,7 @@ const unsigned long	commit_id = 2078;
  * reality, I have decided to start doing that with EPIC.  These names
  * are intentionally and maliciously silly.  Complaints will be ignored.
  */
-const char ridiculous_version_name[] = "Secondment";
+const char ridiculous_version_name[] = "Sockdolager";
 
 #define __need_putchar_x__
 #include "status.h"
@@ -74,6 +74,7 @@ const char ridiculous_version_name[] = "Secondment";
 #include "termx.h"
 #include "exec.h"
 #include "screen.h"
+#include "lastlog.h"
 #include "log.h"
 #include "server.h"
 #include "hook.h"
@@ -149,7 +150,7 @@ const char	*unknown_userhost = "<UNKNOWN>@<UNKNOWN>";
 int		dead = 0;
 
 /* The number of pending SIGINTs (^C) still unprocessed. */
-volatile int	cntl_c_hit = 0;
+volatile sig_atomic_t	cntl_c_hit = 0;
 
 /* This is 1 if we are in the foreground process group */
 int		foreground = 1;
@@ -169,6 +170,8 @@ int		do_window_notifies = 1;
 jmp_buf		panic_jumpseat;
 int		system_reset = 0;
 
+intmax_t	sequence_point = 0;
+
 /*
  * If set, outbound connections will be bind()ed to the address
  * specified.  if unset, the default address for your host will
@@ -331,7 +334,7 @@ die_now:
 	exit(1);
 }
 
-volatile int	dead_children_processes;
+volatile sig_atomic_t	dead_children_processes;
 
 /* 
  * This is needed so that the fork()s we do to read compressed files dont
@@ -342,7 +345,7 @@ static SIGNAL_HANDLER(child_reap)
 	dead_children_processes = 1;
 }
 
-volatile int	segv_recurse = 0;
+volatile sig_atomic_t	segv_recurse = 0;
 
 /* sigsegv: something to handle segfaults in a nice way */
 static SIGNAL_HANDLER(coredump)
@@ -451,15 +454,17 @@ static SIGNAL_HANDLER(sig_user2)
 
 static	void	show_version (void)
 {
-	printf("ircII %s (Commit id: %lu) (Date of release: %s)\n\r", 
-			irc_version, commit_id, internal_version);
+	printf("ircII %s (Commit id: %lu) (Date of release: %s) (git: %s)\n\r", 
+			irc_version, commit_id, internal_version, git_commit);
 	printf("Compile metadata: %s\n", compile_info);
 	printf("Compiler: %s\n", compiler_version);
 	printf("Configure options: %s\n", configure_args);
 	printf("Compilation FLAGS: %s\n", compile_cflags);
 	printf("Compilation LIBS: %s\n", compile_libs);
 	printf("Compilation link: %s\n", final_link);
-	exit (0);
+	printf("OpenSSL version: %#8.8lx\n", OpenSSL_version_num());
+	printf("OpenSSL version: %s\n", OpenSSL_version(OPENSSL_VERSION));
+	exit(0);
 }
 
 /*
@@ -845,10 +850,10 @@ static void	do_signals(void)
 	{
 		while (signals_caught[sig_no])
 		{
-			do_hook(SIGNAL_LIST, "%d %d", sig_no,
-				signals_caught[sig_no]);
-			do_hook(SIGNAL_LIST, "%s %d", get_signal_name(sig_no),
-				signals_caught[sig_no]);
+			do_hook(SIGNAL_LIST, "%d %ld", sig_no,
+				(long)signals_caught[sig_no]);
+			do_hook(SIGNAL_LIST, "%s %ld", get_signal_name(sig_no),
+				(long)signals_caught[sig_no]);
 			signals_caught[sig_no]--;
 		}
 	}
@@ -877,6 +882,8 @@ static	int		level = 0,
 			last_warn = 0;
 	Timeval		timer;
 
+	sequence_point++;
+
 	if (system_reset)
 	{
 		int	i;
@@ -982,6 +989,9 @@ static	int		level = 0,
 	if (need_redraw)
 		redraw_all_screens();
 
+	if (x_debug & DEBUG_SEQUENCE_POINTS)
+		update_all_status();
+
 	/* Make sure all the windows and status bars are made current */
 	update_all_windows();
 
@@ -1010,9 +1020,13 @@ void    load_ircrc (void)
 	if (startup_file || quick_startup)
 		return;
 
-	if (access(epicrc_file, R_OK) == 0)
+	/* 
+	 * epicrc_file and ircrc_file can't be NULL here, but try 
+	 * telling clang's static analyzer that... bleh
+	 */
+	if (epicrc_file && access(epicrc_file, R_OK) == 0)
 		startup_file = malloc_strdup(epicrc_file);
-	else if (access(ircrc_file, R_OK) == 0)
+	else if (ircrc_file && access(ircrc_file, R_OK) == 0)
 		startup_file = malloc_strdup(ircrc_file);
 	else
 		startup_file = malloc_strdup("global");
@@ -1051,6 +1065,7 @@ int 	main (int argc, char *argv[])
 	fprintf(stderr, "Version (%s), Commit Id (%lu) -- Date (%s)\n", 
 				irc_version, commit_id, internal_version);
 	fprintf(stderr, "%s\n", compile_info);
+	fprintf(stderr, "OpenSSL version: %#8.8lx\n", OpenSSL_version_num());
 
 #ifndef NO_JOB_CONTROL
 	/* If we're a bot, do the bot thing. */
@@ -1113,7 +1128,7 @@ int 	main (int argc, char *argv[])
 		init_variables_stage2();
 		permit_status_update(1);
 		build_status(NULL);
-		update_input(NULL, UPDATE_ALL);
+		update_input(-1, UPDATE_ALL);
 	}
 	else
 	{
