@@ -56,6 +56,7 @@ typedef struct	lastlog_stru
 	time_t	created;
 	time_t	expires;
 	int	visible;
+	int	needed;
 	intmax_t refnum;
 	int	window;
 	int	dead;
@@ -209,6 +210,8 @@ intmax_t	add_to_lastlog (int window, const char *line)
 	Lastlog *new_l;
 	Mask	mask;
 
+	window = get_window_refnum(window);
+
 	new_l = (Lastlog *)new_malloc(sizeof(Lastlog));
 	new_l->dead = 0;
 	new_l->refnum = global_lastlog_refnum++;
@@ -254,6 +257,8 @@ intmax_t	add_to_lastlog (int window, const char *line)
 	else
 		new_l->visible = 0;
 
+	new_l->needed = 1;
+
 	/* * * */
 	return new_l->refnum;
 }
@@ -270,6 +275,8 @@ void 	trim_lastlog (int window)
 {
 	Lastlog *item;
 
+	window = get_window_refnum(window);
+
 	if (get_window_lastlog_size(window) <= get_window_lastlog_max(window))
 		return;
 
@@ -302,6 +309,8 @@ void 	truncate_lastlog (int window)
 {
 	Lastlog *item;
 
+	window = get_window_refnum(window);
+
 	debuglog("truncate_lastlog: Preparing to truncate lastlog for window %d.",
 			get_window_user_refnum(window));
 	debuglog("truncate_lastlog: Will remove %d entr(y/ies) from window %d",
@@ -317,6 +326,28 @@ void 	truncate_lastlog (int window)
 	}
 }
 
+/* 
+ * A window may repudiate a lastlog item which means it won't show up
+ * upon a scrollback rebuild
+ */
+void	dont_need_lastlog_item (int window, intmax_t item_refnum)
+{
+	Lastlog *item;
+
+	window = get_window_refnum(window);
+
+	item = oldest_lastlog_for_window(window);
+	while (item)
+	{
+		Lastlog *next_item = newer_lastlog_entry(item, window);
+
+		if (item->refnum == item_refnum)
+			item->needed = 0;
+		item = next_item;
+	}
+
+}
+
 /*
  * clear_level_from_lastlog: Removes all items of the given level(s)
  * from a window, unconditionally and irreversibly
@@ -325,6 +356,8 @@ void 	clear_level_from_lastlog (int window, Mask *levels)
 {
 	Lastlog *item;
 
+	window = get_window_refnum(window);
+
 	item = oldest_lastlog_for_window(window);
 	while (item)
 	{
@@ -350,6 +383,8 @@ void 	clear_regex_from_lastlog (int window, const char *regex)
 	regex_t	preg;
 	int	errcode;
 
+	window = get_window_refnum(window);
+
 	if (!regex)
 		return;
 
@@ -1404,8 +1439,15 @@ void	reconstitute_scrollback (int window)
 
 	for (li = lastlog_oldest; li; li = li->newer)
 	{
-	    if (li->window == window)
+	    if (li->window == window && li->needed)
+	    {
+		debuglog("reconstitute_scrollback: YES window %d (%d) refnum %d msg %s", li->window, window, li->refnum, li->msg);
 		add_to_window_scrollback(window, li->msg, li->refnum);
+	    }
+	    else
+	    {
+		debuglog("reconstitute_scrollback: NO   window %d (%d) refnum %d msg %s", li->window, window, li->refnum, li->msg);
+	    }
 	}
 }
 	
