@@ -440,7 +440,6 @@ const	char	*prefix;
 			if (is_me(server, nick))
 				chan->voice = 1;
 			isvoice = 1;
-			break;
 		}
 		else if (*nick == '@')
 		{
@@ -455,7 +454,6 @@ const	char	*prefix;
 					half_assed = -1;
 			}
 			ischop = 1;
-			break;
 		}
 		else if (*nick == '%')
 		{
@@ -468,7 +466,6 @@ const	char	*prefix;
 					isvoice = -1;
 			}
 			half_assed = 1;
-			break;
 		}
 		else
 		{
@@ -1433,7 +1430,7 @@ void 	set_channel_window (const char *channel, int server, int window_, int as_c
 		 */
 		if (is_current_now && tmp->window == window && as_current)
 		{
-			yell("%d:%s is already current window of %d", server, channel, get_window_user_refnum(window));
+			debuglog("%d:%s is already current window of %d", server, channel, get_window_user_refnum(window));
 			return;
 		}
 
@@ -1760,7 +1757,7 @@ int	window_claims_channel (int window, int winserv, const char *channel)
 		 * exactly which channel is claimable at this moment: i just want to 
 		 * make sure you are claiming what you think you are claiming.
 		 */
-		if (tmp->claimable)
+		if (tmp->claimable == 1)
 		{
 			/* Make sure you think you're claiming the correct channel */
 			if (my_stricmp(tmp->channel, channel))
