@@ -69,6 +69,9 @@ static	void	strip_modes (const char *, const char *, const char *);
 /* User and host information from server 2.7 */
 const char	*FromUserHost = empty_string;
 
+/* CAP tags information */
+const char	*Tags = empty_string;
+
 /*
  * is_channel: determines if the argument is a channel.  If it's a number,
  * begins with MULTI_CHANNEL and has no '*', or STRING_CHANNEL, then its a
@@ -179,6 +182,21 @@ static void 	BreakArgs (char *Input, const char **Sender, const char **OutPut)
 		OutPut[ArgCount] = NULL;
 	ArgCount = 0;
 
+	/*
+	 * Look for CAP tags.
+	 * @aaa=bbb;ccc;example.com/ddd=eee <rfc1459 message>
+	 */
+	if (*Input == '@')
+	{
+		Tags = ++Input;
+
+		while (*Input && *Input != space)
+			Input++;
+		while (*Input == space)
+			*Input++ = 0;
+	} else
+		Tags = empty_string;
+
 	/*
 	 * The RFC describes it fully, but in a short form, a line looks like:
 	 * [:sender[!user@host]] COMMAND ARGUMENT [[:]ARGUMENT]{0..14}
@@ -652,7 +670,7 @@ static void	p_error (const char *from, const char *comm, const char **ArgList)
 		say("%s %s", from, the_error);
 }
 
-static void	p_channel (const char *from, const char *comm, const char **ArgList)
+static void	p_join (const char *from, const char *comm, const char **ArgList)
 {
 	const char	*channel;
 	char 	*c;
@@ -829,7 +847,8 @@ static void	p_ping (const char *from, const char *comm, const char **ArgList)
 	if (!(message = ArgList[0]))
 		{ rfc1459_odd(from, comm, ArgList); return; }
 
-	send_to_server("PONG %s", message);
+	if (do_hook(PING_LIST, "%s %s", from, message))
+		send_to_server("PONG %s", message);
 }
 
 static void	p_silence (const char *from, const char *comm, const char **ArgList)
@@ -944,8 +963,7 @@ static void	p_mode (const char *from, const char *comm, const char **ArgList)
 		type = "for user";
 	}
 
-	if (check_ignore_channel(from, FromUserHost, 
-					target, LEVEL_MODE) == IGNORED)
+	if (check_ignore_channel(from, FromUserHost, target, LEVEL_MODE) == IGNORED)
 		goto do_update_mode;
 
 	if (new_check_flooding(from, FromUserHost, target, changes, LEVEL_MODE))
@@ -953,8 +971,7 @@ static void	p_mode (const char *from, const char *comm, const char **ArgList)
 
 	l = message_from(m_target, LEVEL_MODE);
 	if (do_hook(MODE_LIST, "%s %s %s", from, target, changes))
-	    say("Mode change \"%s\" %s %s by %s",
-					changes, type, target, from);
+	    say("Mode change \"%s\" %s %s by %s", changes, type, target, from);
 	pop_message_from(l);
 
 do_update_mode:
@@ -1476,7 +1493,7 @@ static protocol_command rfc1459[] = {
 {	"INFO",		NULL,		0		},
 {	"INVITE",	p_invite,	0		},
 {	"ISON",		NULL,		PROTO_QUOTEBAD	},
-{	"JOIN",		p_channel,	0		},
+{	"JOIN",		p_join,		0		},
 {	"KICK",		p_kick,		0		},
 {	"KILL",		p_kill,		0		},
 {	"LINKS",	NULL,		0		},
