@@ -43,6 +43,8 @@
 #include "vars.h"
 #include "hook.h"
 #include "input.h"
+#include "levels.h"
+#include "lastlog.h"
 #include "commands.h"
 #include "window.h"
 #include "screen.h"
@@ -107,6 +109,7 @@ STATUS_FUNCTION(status_swappable);
 STATUS_FUNCTION(status_activity);
 STATUS_FUNCTION(status_window_prefix);
 STATUS_FUNCTION(status_server_status);
+STATUS_FUNCTION(status_sequence_point);
 
 /* These are used as placeholders for some expandos */
 static	char	*mode_format 		= (char *) 0;
@@ -119,6 +122,7 @@ static	char	*cpu_saver_format 	= (char *) 0;
 static	char	*mail_format 		= (char *) 0;
 static	char	*nick_format		= (char *) 0;
 static	char	*server_format 		= (char *) 0;
+static	char	*sp_format 		= (char *) 0;
 static	char	*notify_format 		= (char *) 0;
 
 	Status	main_status;
@@ -219,6 +223,7 @@ struct status_formats status_expandos[] = {
 { 2, '7', status_user,	 	NULL,			NULL },
 { 2, '8', status_user,	 	NULL, 			NULL },
 { 2, '9', status_user,	 	NULL, 			NULL },
+{ 2, 'P', status_sequence_point, &sp_format,		&STATUS_SEQUENCE_POINT_VAR },
 { 2, 'S', status_server,        &server_format,     	&STATUS_SERVER_VAR },
 { 2, 'W', status_window,	NULL, 			NULL },
 { 2, '+', status_mode,		&mode_format,       	&STATUS_MODE_VAR },
@@ -490,9 +495,9 @@ int	make_status (int window_, Status *status)
 	char	rhs_buffer  [BIG_BUFFER_SIZE + 1];
 	const char	*func_value [MAX_FUNCTIONS];
 	size_t		save_size;
-	Screen	*	screen;
 	int		anything_changed = 0;
 	int		user_refnum;
+	int		screen_columns;
 
 	/* Should this be a panic? */
 	if (window_ == 0 || status == NULL)
@@ -511,18 +516,20 @@ int	make_status (int window_, Status *status)
 	}
 
 	/* For hidden windows, we just pretend they're on the main screen */
-	if (!(screen = get_window_screen(window_)))
+	if (get_window_screennum(window_) < 0)
 	{
 		debuglog("make_status(%d) -- updating hidden window", user_refnum);
-		screen = main_screen;
+		screen_columns = get_screen_columns(main_screen);
 	}
+	else
+		screen_columns = get_screen_columns(get_window_screennum(window_));
 
 	for (status_line = 0; status_line < status->number; status_line++)
 	{
-	int		fillchar;
-	char	*lhp = lhs_buffer,
+		int	fillchar;
+		char	*lhp = lhs_buffer,
 			*rhp = rhs_buffer;
-	char 	*cp,
+		char 	*cp,
 			*str = NULL;
 	const char *	start_rhs = 0;
 		int	pr_lhs = 0,
@@ -672,12 +679,14 @@ int	make_status (int window_, Status *status)
                          */
                         else if (code_point == 6)
                         {
-                                /* Copy the next 5 values */
-                                *cp++ = 6;
-                                *cp++ = *s++;
-                                *cp++ = *s++;
-                                *cp++ = *s++;
-                                *cp++ = *s++;
+				size_t numbytes = 0;
+
+				*cp++ = 6;
+
+				/* XXX BIG_BUFFER_SIZE here is wrong. */
+				copy_internal_attribute(s, cp, BIG_BUFFER_SIZE, &numbytes);
+				s += numbytes;
+				cp += numbytes;
                         }
 
 			/*
@@ -717,7 +726,7 @@ int	make_status (int window_, Status *status)
 			/*
 			 * Dont allow more than CO printable characters
 			 */
-			if (pr_lhs + pr_rhs >= screen->co)
+			if (pr_lhs + pr_rhs >= screen_columns)
 			{
 				*cp = 0;
 				break;
@@ -745,7 +754,7 @@ int	make_status (int window_, Status *status)
 			}
 			ucs_to_utf8(fillchar, utf8str, sizeof(utf8str));
 
-			numf = screen->co - pr_lhs - 1;
+			numf = screen_columns - pr_lhs - 1;
 			if (start_rhs)
 				numf -= pr_rhs;
 
@@ -852,7 +861,7 @@ int	redraw_status (int window_, Status *status)
 			continue;
 		}
 
-		if (dumb_mode || !foreground || !get_window_screen(window_))
+		if (dumb_mode || !foreground || get_window_screennum(window_) < 0)
 		{
 			debuglog("redraw_status(%d/%d/%d): dumb/bg/hidden",
 				user_refnum, status_line, line);
@@ -862,7 +871,7 @@ int	redraw_status (int window_, Status *status)
 		/*
 		 * Output the status line to the screen
 		 */
-		output_screen = get_window_screen(window_);
+		output_screen = get_window_screennum(window_);
 		term_move_cursor(0, get_window_bottom(window_) + status_line);
 		output_with_count(status_str, 1, 1);
 		debuglog("redraw_status(%d/%d/%d): status redrawn",
@@ -997,7 +1006,7 @@ int     permit_status_update (int flag)
 /*
  * This tests to see if the window IS the current window on its screen
  */
-#define IS_CURRENT_WINDOW (get_window_screen(window_) && get_window_screen(window_)->input_window == window_)
+#define IS_CURRENT_WINDOW (get_window_screennum(window_) >= 0 && get_screen_input_window(get_window_screennum(window_)) == window_)
 
 /*
  * This tests to see if all expandoes are to appear in all status bars
@@ -1058,8 +1067,9 @@ int     permit_status_update (int flag)
  */
 #define STATUS_VARS \
 	static char *	my_bufferx = NULL; \
-	static int 	my_bufferxsize = 64; \
-	       int	actual_size;
+	static size_t 	my_bufferxsize = 64; \
+	       ssize_t	actual_size; \
+		char *	expanded_arg = NULL;
 
 /* After you change 'my_bufferxspace', call this to update 'my_bufferx' */
 #define CHECK \
@@ -1073,7 +1083,7 @@ int     permit_status_update (int flag)
 #define RECHECK \
 	if (actual_size < 0) 	/* Die Die Die */ \
 		my_bufferxsize += 16;	\
-	else if (actual_size < my_bufferxsize) \
+	else if (actual_size < (ssize_t)my_bufferxsize) \
 		break; \
 	else					\
 		my_bufferxsize = actual_size + 1; \
@@ -1087,11 +1097,22 @@ int     permit_status_update (int flag)
  */
 #define PRESS(fmt, arg) \
 	if (! fmt ) return empty_string; \
+\
+	if (get_int_var(STATUS_DOES_EXPANDOS_VAR)) { 	\
+		size_t	siz;  				\
+		siz = strlen(arg) * 2 + 6;		\
+		expanded_arg = alloca(siz); 		\
+		*expanded_arg = 0; 			\
+		double_quote(arg, "$\\", expanded_arg, siz); \
+	} else { \
+		expanded_arg = LOCAL_COPY(arg); \
+	} \
+\
 	CHECK \
 	do { \
-		actual_size = snprintf(my_bufferx, my_bufferxsize, fmt, arg); \
+		actual_size = (ssize_t)snprintf(my_bufferx, my_bufferxsize, fmt, expanded_arg); \
 		RECHECK \
-	} while (1);
+	} while (1);  \
 
 /*
  * Return the return buffer.  The reason this is not part of 'PRESS' is 
@@ -1296,17 +1317,26 @@ STATUS_FUNCTION(status_mode)
 
 	if (map == 0 || map == 1)
 	{
+	    /* This now gets handled by PRESS() for everything */
+#if 0
 	    /*
 	     * This gross hack is required to make sure that the 
 	     * channel key doesnt accidentally contain anything 
 	     * dangerous...
+	     *
+	     * XXX -is this still necessary? 
 	     */
 	    if (get_int_var(STATUS_DOES_EXPANDOS_VAR) && strchr(mode, '$'))
 	    {
-		char *mode2 = alloca(strlen(mode) * 2 + 1);
-		double_quote(mode, "$", mode2);
+		size_t	siz;
+		char *	mode2;
+
+		siz = strlen(mode) * 2 + 2;
+		mode2 = alloca(siz);
+		double_quote(mode, "$", mode2, siz);
 		mode = mode2;
 	    }
+#endif
 	}
 	else if (map == 2 || map == 3)
 	{
@@ -1653,9 +1683,9 @@ STATUS_FUNCTION(status_window)
 	switch (map)
 	{
 		case 0:
-			if (!get_window_screen(window_))
+			if (get_window_screennum(window_) < 0)
 				break;
-			if (number_of_windows_on_screen(get_window_screen(window_)) <= 1)
+			if (get_screen_visible_windows(get_window_screennum(window_)) <= 1)
 				break;
 			/* FALLTHROUGH */
 		case 3:
@@ -1685,7 +1715,7 @@ STATUS_FUNCTION(status_refnum_real)
 {
 	STATUS_VARS
 
-	PRESS("%d", get_window_user_refnum(window_));
+	PRESS("%s", ltoa(get_window_user_refnum(window_)));
 	RETURN
 }
 
@@ -1892,3 +1922,19 @@ BUILT_IN_FUNCTION(function_status_oneoff, input)
 	RETURN_MSTR(retval);
 }
 
+STATUS_FUNCTION(status_sequence_point)
+{
+	STATUS_VARS
+	char resultstr[100];
+
+	if (x_debug & DEBUG_SEQUENCE_POINTS)
+	{
+		snprintf(resultstr, sizeof(resultstr), UINTMAX_FORMAT, sequence_point);
+		PRESS(sp_format, resultstr);
+		RETURN
+	}
+	else
+		return empty_string;
+}
+
+
